:construction: under construction :construction: 

## Define a bronze table

## Define a silver table

## Define a silver star table

## Define a gold table

## Define a table as streaming or static

## Define a column with an SQL expression 

## Define a column with a built-in spark function

## Define a column with a custom spark function

